==> kadu-0.4.1.tar.bz2: kadu/modules/autoaway/translations/autoaway_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Automatyczny status &quot;zajęty&quot;</translation>
    </message>
    <message>
        <source>Set status to away after </source>
        <translation>Zmień status po: </translation>
    </message>
    <message>
        <source>Check idle every </source>
        <translation> Sprawdź bezczynność co:</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Włącz auto niewidoczny</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Włącz autorozłączenie</translation>
    </message>
    <message>
        <source>Set status to invisible after </source>
        <translation>Ustaw status niewidoczny po:  </translation>
    </message>
    <message>
        <source>Disconnect after </source>
        <translation>Rozłącz po:  </translation>
    </message>
    <message>
        <source>Enable AutoStatus</source>
        <translation>Włącz AutoStatus</translation>
    </message>
    <message>
        <source>Autorestore status</source>
        <translation>Autoprzywracanie statusu</translation>
    </message>
    <message>
        <source>Auto change status</source>
        <translation>Zmień na opis </translation>
    </message>
    <message>
        <source>AutoStatus Description</source>
        <translation>Opis Autostatusu</translation>
    </message>
</context>
<context>
    <name>AutoAwaySlots</name>
    <message>
        <source>Don&apos;t change the description</source>
        <translation>Nie zmieniaj opisu</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Add in front of description</source>
        <translation>Dodaj na początku opisu</translation>
    </message>
    <message>
        <source>Add at the back of description</source>
        <translation>Dodaj na końcu opisu</translation>
    </message>
</context>
</TS>

==> kadu-0.4.3.tar.bz2: kadu/modules/autoaway/translations/autoaway_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Automatyczny status &quot;zajęty&quot;</translation>
    </message>
    <message>
        <source>Set status to away after </source>
        <translation>Zmień status po: </translation>
    </message>
    <message>
        <source>Check idle every </source>
        <translation> Sprawdź bezczynność co:</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Włącz auto ukryty</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Włącz autorozłączenie</translation>
    </message>
    <message>
        <source>Set status to invisible after </source>
        <translation>Ustaw status ukryty po:  </translation>
    </message>
    <message>
        <source>Disconnect after </source>
        <translation>Rozłącz po:  </translation>
    </message>
    <message>
        <source>Enable AutoStatus</source>
        <translation>Włącz AutoStatus</translation>
    </message>
    <message>
        <source>Autorestore status</source>
        <translation>Autoprzywracanie statusu</translation>
    </message>
    <message>
        <source>Auto change status</source>
        <translation>Zmień na opis </translation>
    </message>
    <message>
        <source>AutoStatus Description</source>
        <translation>Opis Autostatusu</translation>
    </message>
</context>
<context>
    <name>AutoAwaySlots</name>
    <message>
        <source>Don&apos;t change the description</source>
        <translation>Nie zmieniaj opisu</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Add in front of description</source>
        <translation>Dodaj na początku opisu</translation>
    </message>
    <message>
        <source>Add at the back of description</source>
        <translation>Dodaj na końcu opisu</translation>
    </message>
</context>
</TS>
